##
##  ices.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2009 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base 0.4
%define       V_snap 20091201

#   package information
Name:         ices
Summary:      MP3 Streaming Source Client for Icecast
URL:          http://www.icecast.org/ices.php
Vendor:       Alexander Havang
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        Audio
License:      GPL
Version:      %{V_base}.%{V_snap}
Release:      20091202

#   list of sources
Source0:      http://people.xiph.org/~brendan/snapshots/ices0/ices-%{V_base}-%{V_snap}.tar.gz
Source1:      ices.conf
Source2:      rc.ices

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823
PreReq:       OpenPKG, openpkg >= 20060823
BuildPreReq:  libshout, libxml, vorbis-libs, flac, lame, perl
PreReq:       libshout, libxml, vorbis-libs, flac, lame, perl
AutoReq:      no
AutoReqProv:  no

%description
    Ices, armed with a list of MP3 files, sends a continuous stream of
    MP3 data to an Icecast server. The server is then responsible for
    accepting client connections and feeding the MP3 stream to them.

%track
    prog ices = {
        version   = %{V_base}-%{V_snap}
        url       = http://people.xiph.org/~brendan/snapshots/ices0/
        regex     = ices-(__VER__\-\d{4}\d{2}01)\.tar\.gz
    }

%prep
    %setup -q -n ices-%{V_base}

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --sysconfdir=%{l_prefix}/etc/ices \
        --with-xml-config=%{l_prefix}/bin/xml2-config \
        --with-perl=%{l_prefix}/bin/perl \
        --with-vorbis=%{l_prefix} \
        --with-lame=%{l_prefix} \
        --with-flac=%{l_prefix}

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    rm -rf $RPM_BUILD_ROOT
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"

    #   install default configuration

    #   post-adjust installation
    mv  $RPM_BUILD_ROOT%{l_prefix}/etc/ices/modules/ices.pm.dist \
        $RPM_BUILD_ROOT%{l_prefix}/etc/ices/modules/ices.pm

    #   strip down installation
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/doc/ices >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/ices/ices.conf.dist >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/ices/modules/ices.py.dist >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/etc/ices/modules/ices.sh.dist >/dev/null 2>&1 || true

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE ices.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/ices/

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE rc.ices} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   create run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/ices

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/ices/*' \
        '%attr(-,%{l_nusr},%{l_ngrp}) %{l_prefix}/var/ices'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} ices status 2>/dev/null`
    [ ".$ices_active" = .yes ] && %{l_rc} ices restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} ices stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/ices/* >/dev/null 2>&1 || true
    exit 0

